@@ -8,7 +8,7 @@ import (
 
 	"github.com/aquasecurity/tfsec/internal/pkg/formatter"
 
-	"github.com/aquasecurity/tfsec/pkg/scanner"
+	scanner "github.com/aquasecurity/defsec/scanners/terraform"
 
 	"github.com/aquasecurity/defsec/formatters"
 	"github.com/aquasecurity/defsec/providers"
@@ -74,7 +74,9 @@ func outputFormat(addExtension bool, baseFilename string, format string, dir str
 		WithGroupingEnabled(!disableGrouping).
 		WithLinksFunc(gatherLinks).
 		WithBaseDir(dir).
-		WithMetricsEnabled(!conciseOutput)
+		WithMetricsEnabled(!conciseOutput).
+		WithIncludeIgnored(includeIgnored).
+		WithIncludePassed(includePassed)
 
 	var alsoStdout bool
 
